import logging

logger = logging.getLogger("checkpointing")
"""
Logger used by all components of the checkpointing module.
"""

logger.setLevel(logging.CRITICAL)
